@@ -115,7 +115,7 @@ chisq_to_phi <- function(chisq, n, nrow = 2, ncol = 2,
                          ci = 0.95, alternative = "greater",
                          ...) {
   if ((!missing(nrow) && nrow != 2) || (!missing(ncol) && ncol != 2)) {
-    stop("Phi is not appropriate for non-2x2 tables.", call. = FALSE)
+    insight::format_error("Phi is not appropriate for non-2x2 tables.")
   }
 
   res <- .chisq_to_generic_phi(chisq, n, nrow, ncol,
@@ -141,7 +141,7 @@ chisq_to_phi <- function(chisq, n, nrow = 2, ncol = 2,
 
 #' @rdname convert_chisq
 #' @export
-chisq_to_cohens_w <- function(chisq, n, nrow, ncol,
+chisq_to_cohens_w <- function(chisq, n, nrow, ncol, p,
                               ci = 0.95, alternative = "greater",
                               ...) {
   res <- .chisq_to_generic_phi(chisq, n, nrow, ncol,
@@ -154,7 +154,12 @@ chisq_to_cohens_w <- function(chisq, n, nrow, ncol,
     if (ncol > 2 && nrow > 2) {
       max_possible <- sqrt((pmin(ncol, nrow) - 1))
     } else if (ncol == 1 || nrow == 1) {
-      max_possible <- Inf # really is chisqMax, but can't compute it without p
+      if (missing(p)) {
+        max_possible <- Inf # really is chisqMax, but can't compute it without p
+      } else {
+        q <- min(p / sum(p))
+        max_possible <- sqrt((1 - q) / q)
+      }
     }
 
     if (attr(res, "alternative") == "greater") {
@@ -174,7 +179,7 @@ chisq_to_cramers_v <- function(chisq, n, nrow, ncol,
                                ci = 0.95, alternative = "greater",
                                ...) {
   if (nrow == 1 || ncol == 1) {
-    stop("Cramer's V not applicable to goodness-of-fit tests.", call. = FALSE)
+    insight::format_error("Cramer's V not applicable to goodness-of-fit tests.")
   }
 
   res <- .chisq_to_generic_phi(chisq, n, nrow, ncol,
@@ -197,7 +202,7 @@ chisq_to_cramers_v <- function(chisq, n, nrow, ncol,
   # Convert
   res[grepl("^(phi|CI_)", colnames(res))] <-
     lapply(res[grepl("^(phi|CI_)", colnames(res))], "/", y = div)
-  colnames(res)[1] <- gsub("phi", "Cramers_v", colnames(res)[1])
+  colnames(res)[1] <- gsub("phi", "Cramers_v", colnames(res)[1], fixed = TRUE)
 
   if ("CI" %in% colnames(res)) {
     if (attr(res, "alternative") == "greater") {
@@ -215,7 +220,7 @@ chisq_to_tschuprows_t <- function(chisq, n, nrow, ncol,
                                   ci = 0.95, alternative = "greater",
                                   ...) {
   if (nrow == 1 || ncol == 1) {
-    stop("Tschuprow's T not applicable to goodness-of-fit tests.", call. = FALSE)
+    insight::format_error("Tschuprow's T not applicable to goodness-of-fit tests.")
   }
 
   res <- .chisq_to_generic_phi(chisq, n, nrow, ncol,
@@ -248,11 +253,11 @@ chisq_to_fei <- function(chisq, n, nrow, ncol, p,
                          ...) {
   if (!missing(nrow) && !missing(ncol)) {
     if (!1 %in% c(nrow, ncol)) {
-      stop("Fei is only applicable to goodness of fit tests.", call. = FALSE)
+      insight::format_error("Fei is only applicable to goodness of fit tests.")
     }
 
     if (!length(p) %in% c(ncol, nrow)) {
-      stop("Length of `p` must match number of rows/columns.", call. = FALSE)
+      insight::format_error("Length of `p` must match number of rows/columns.")
     }
   }
 
